@@ -69,7 +69,7 @@ def augments(cls_cpp: Type[Any]):
     wrapper classes and subclasses can become problematic if the call stack
     crosses the C++/Python boundary multiple times.
 
-    Any existing methods may be used, regardless of whether they defined
+    Any existing methods may be used, regardless of whether they are defined
     elsewhere in the support class or in the target class.
 
     For data fields to work, including @property accessors, the target class must be
@@ -157,7 +157,7 @@ class Extend_Object:
             return self.keys()
         return None
 
-    def emplace(self, other: Object):
+    def emplace(self, other: Object, retain=(Name.Parent,)):
         """Copy all items from other without making a new object.
 
         Particularly when working with pages, it may be desirable to remove all
@@ -165,6 +165,9 @@ class Extend_Object:
         of it, in a way that preserves all links and references to the original
         page. (Or similarly, for other Dictionary objects in a PDF.)
 
+        Any Dictionary keys in the iterable *retain* are preserved. By default,
+        /Parent is retained.
+
         When a page is assigned (``pdf.pages[0] = new_page``), only the
         application knows if references to the original the original page are
         still valid. For example, a PDF optimizer might restructure a page
@@ -181,11 +184,22 @@ class Extend_Object:
             >>> pdf.pages[0].emplace(pdf.pages[1])
             >>> pdf.pages[0].objgen
             (16, 0)  # Same object
+
+        .. versionchanged:: 2.11.1
+            Added the *retain* argument.
         """
         if not self.same_owner_as(other):
             raise TypeError("Objects must have the same owner for emplace()")
-        del_keys = set(self.keys()) - set(other.keys())
-        for k in other.keys():
+
+        # .keys() returns strings, so make all strings
+        retain = set(str(k) for k in retain)
+        self_keys = set(self.keys())
+        other_keys = set(other.keys())
+
+        assert all(isinstance(k, str) for k in (retain | self_keys | other_keys))
+
+        del_keys = self_keys - other_keys - retain
+        for k in (k for k in other_keys if k not in retain):
             self[k] = other[k]  # pylint: disable=unsupported-assignment-operation
         for k in del_keys:
             del self[k]  # pylint: disable=unsupported-delete-operation
@@ -275,6 +289,9 @@ class Extend_Pdf:
     def root(self):
         """
         Deprecated alias for .Root, the /Root object of the PDF.
+
+        .. deprecated:: 2.0
+            Use ``.Root``.
         """
         warn("Pdf.root is deprecated; use Pdf.Root", category=DeprecationWarning)
         return self.Root
@@ -317,6 +334,9 @@ class Extend_Pdf:
         You can delete the document information dictionary by deleting this property,
         ``del pdf.docinfo``. Note that accessing the property after deleting it
         will re-create with a new, empty dictionary.
+
+        .. versionchanged: 2.4
+            Added support for ``del pdf.docinfo``.
         """
         if Name.Info not in self.trailer:
             self.trailer.Info = self.make_indirect(Dictionary())
@@ -433,7 +453,7 @@ class Extend_Pdf:
         self, *, page_size: Tuple[Numeric, Numeric] = (612.0, 792.0)
     ) -> Object:
         """
-        Add a blank page to this PD. If pages already exist, the page will be added to
+        Add a blank page to this PDF. If pages already exist, the page will be added to
         the end. Pages may be reordered using ``Pdf.pages``.
 
         The caller may add content to the page by modifying its objects after creating
@@ -766,14 +786,17 @@ class Extend_Pdf:
 
             :meth:`pikepdf.Pdf.remove_unreferenced_resources` before saving
             may eliminate unnecessary resources from the output file if there
-            any objects (such as images) that are referenced in a page's
+            are any objects (such as images) that are referenced in a page's
             Resources dictionary but never called in the page's content stream.
 
         .. note::
 
-            pikepdf can read PDFs will incremental updates, but always
-            any coalesces incremental updates into a single non-incremental
+            pikepdf can read PDFs with incremental updates, but always
+            coalesces any incremental updates into a single non-incremental
             PDF file when saving.
+
+        .. versionchanged:: 2.7
+            Added *recompress_flate*.
         """
         if not filename_or_stream and self._original_filename:
             filename_or_stream = self._original_filename
@@ -817,11 +840,11 @@ class Extend_Pdf:
         lazily loaded. Despite this restriction, pikepdf does not try to use any OS
         services to obtain an exclusive lock on the file. Some applications may
         want to attempt this or copy the file to a temporary location before
-        editing. This behaviour change if *allow_overwriting_input* is set: the whole
+        editing. This behaviour changes if *allow_overwriting_input* is set: the whole
         file is then read and copied to memory, so that pikepdf can overwrite it
         when calling ``.save()``.
 
-        When this is function is called with a stream-like object, you must ensure
+        When this function is called with a stream-like object, you must ensure
         that the data it returns cannot be modified, or undefined behavior will
         occur.
 
@@ -846,7 +869,8 @@ class Extend_Pdf:
             >>> pdf = Pdf.open("test.pdf", password="rosebud")
 
         Args:
-            filename_or_stream: Filename of PDF to open.
+            filename_or_stream: Filename or Python readable and seekable file
+                stream of PDF to open.
             password: User or owner password to open an
                 encrypted PDF. If the type of this parameter is ``str``
                 it will be encoded as UTF-8. If the type is ``bytes`` it will
@@ -887,6 +911,15 @@ class Extend_Pdf:
             TypeError: If the type of ``filename_or_stream`` is not
                 usable.
             FileNotFoundError: If the file was not found.
+
+        Note:
+            When *filename_or_stream* is a stream and the stream is located on a
+            network, pikepdf assumes that the stream using buffering and read caches
+            to achieve reasonable performance. Streams that fetch data over a network
+            in response to every read or seek request, no matter how small, will
+            perform poorly. It may be easier to download a PDF from network to
+            temporary local storage (such as ``io.BytesIO``), manipulate it, and
+            then re-upload it.
         """
         if isinstance(filename_or_stream, bytes) and filename_or_stream.startswith(
             b'%PDF-'
@@ -1021,6 +1054,8 @@ class Extend_Page:
 
         Example:
             >>> resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
+
+        .. versionadded: 2.3
         """
         if not Name.Resources in self.obj:
             self.obj.Resources = Dictionary()
